@@ -8,6 +8,9 @@ class ConditionalSegmentBaseHandler:
     Extract lineage from a segment when the segment match the condition
     """
 
+    def __init__(self, dialect: str) -> None:
+        self.dialect = dialect
+
     def handle(self, segment: BaseSegment, holder: SubQueryLineageHolder) -> None:
         """
         Handle the segment, and update the lineage result accordingly in the holder
@@ -37,6 +40,9 @@ class SegmentBaseHandler:
     Extract lineage from a specific segment
     """
 
+    def __init__(self, dialect: str) -> None:
+        self.dialect = dialect
+
     def handle(self, segment: BaseSegment, holder: SubQueryLineageHolder) -> None:
         """
         :param segment: segment to be handled
