@@ -37,6 +37,8 @@ def extract_as_and_target_segment(
         target = sublist[0]
     elif sublist[0].type == "bracketed":
         target = get_innermost_bracketed(sublist[0])
+    elif sublist[0].type == "keyword" and sublist[0].raw_upper == "FROM":
+        as_segment, target = extract_as_and_target_segment(sublist[1])
     else:
         target = sublist[0].segments[0]
     return as_segment, target
@@ -118,13 +120,19 @@ def is_subquery(segment: BaseSegment) -> bool:
         token = get_innermost_bracketed(
             segment if segment.type == "bracketed" else segment.segments[0]
         )
-        # check if innermost parenthesis contains SELECT
+        # check if innermost parenthesis contains SELECT, SET, or WITH COMPOUND
         sub_token = (
             token.get_child("select_statement")
             or token.get_child("set_expression")
+            or token.get_child("with_compound_statement")
             or (
                 token.get_child("expression")
-                and token.get_child("expression").get_child("select_statement")
+                and (
+                    token.get_child("expression").get_child("select_statement")
+                    or token.get_child("expression").get_child(
+                        "with_compound_statement"
+                    )
+                )
             )
         )
         if sub_token is not None:
@@ -358,6 +366,12 @@ def retrieve_extra_segment(segment: BaseSegment) -> Iterable[BaseSegment]:
         for sgmnt in segment.get_child("from_expression").segments:
             if sgmnt.type == "join_clause":
                 yield sgmnt
+        # handle bracketed expression
+        bracketed_exp = segment.get_child("from_expression").get_child("bracketed")
+        if bracketed_exp and isinstance(bracketed_exp, BaseSegment):
+            for sgmnt in bracketed_exp.segments:
+                if sgmnt.type == "join_clause":
+                    yield sgmnt
 
 
 def get_grandchild(
