@@ -179,16 +179,8 @@ SELECT row_number() over (partition BY col1 ORDER BY col2 DESC) AS rnum
 FROM tab2"""
     assert_column_lineage_equal(
         sql,
-        [
-            (
-                TestColumnQualifierTuple("col1", "tab2"),
-                TestColumnQualifierTuple("rnum", "tab1"),
-            ),
-            (
-                TestColumnQualifierTuple("col2", "tab2"),
-                TestColumnQualifierTuple("rnum", "tab1"),
-            ),
-        ],
+        [],
+        test_sqlparse=False,
     )
 
 
@@ -205,14 +197,6 @@ FROM tab2"""
                 TestColumnQualifierTuple("col0", "tab2"),
                 TestColumnQualifierTuple("col0", "tab1"),
             ),
-            (
-                TestColumnQualifierTuple("col1", "tab2"),
-                TestColumnQualifierTuple("rnum", "tab1"),
-            ),
-            (
-                TestColumnQualifierTuple("col2", "tab2"),
-                TestColumnQualifierTuple("rnum", "tab1"),
-            ),
             (
                 TestColumnQualifierTuple("col3", "tab2"),
                 TestColumnQualifierTuple("rnum", "tab1"),
@@ -666,9 +650,13 @@ FROM tab2 a
         sql,
         [
             (
-                TestColumnQualifierTuple("col1", None),
+                TestColumnQualifierTuple("col1", "tab2"),
                 TestColumnQualifierTuple("col1", "tab1"),
-            )
+            ),
+            (
+                TestColumnQualifierTuple("col1", "tab3"),
+                TestColumnQualifierTuple("col1", "tab1"),
+            ),
         ],
     )
 
@@ -861,14 +849,11 @@ WHERE rn = 1"""
         sql,
         [
             (
-                TestColumnQualifierTuple("col1", "tab2"),
-                TestColumnQualifierTuple("rn", "tab1"),
-            ),
-            (
-                TestColumnQualifierTuple("col2", "tab2"),
+                TestColumnQualifierTuple("rn", "sub", is_subquery=True),
                 TestColumnQualifierTuple("rn", "tab1"),
             ),
         ],
+        test_sqlparse=False,
     )
 
 
@@ -1286,6 +1271,20 @@ WHEN NOT MATCHED THEN INSERT (k, v) VALUES (b.k, b.v_max)"""
     )
 
 
+# https://github.com/open-metadata/OpenMetadata/issues/7427#issuecomment-2710190700
+# ensure no exception for merge query with column tokens under insert clause
+# TODO: this is invalid query as it is not allowed to have column tokens under insert clause
+# but it's parsable by sqlparse/sqlfluff. Therefore, we should handle this case.
+def test_merge_into_with_with_column_tokens():
+    sql = """MERGE INTO target_table t
+USING source_table s
+ON t.id = s.id
+WHEN NOT MATCHED THEN
+    INSERT (1, 2, 3)
+    VALUES (s.id, s.col1, s.col2)"""
+    assert_column_lineage_equal(sql, [])
+
+
 def test_union_inside_cte():
     sql = """INSERT INTO dataset.target WITH temp_cte AS (SELECT col1 FROM dataset.tab1 UNION ALL
 SELECT col1 FROM dataset.tab2) SELECT col1 FROM temp_cte"""
@@ -1376,3 +1375,64 @@ def test_insert_with_cte():
         ],
         test_sqlparse=False,
     )
+
+
+def test_alias_with_casing():
+    sql = """create or replace view trg_tbl as
+        SELECT
+            ldlg.ld_leg_id
+            ,stpp.PICK_ARVL_RPTD_DTT Actual_Pickup_Arrival
+            ,stpp.PICK_DPTR_RPTD_DTT Actual_Pickup_Departure
+        FROM src_tbl_1 ldlg
+        LEFT JOIN src_tbl_2 STPP
+            ON ldlg.PICK_STOP_ID = stpp.STOP_ID
+        WHERE ldlg.LGST_GRP_CD = 'GEC'
+        AND ldlg.LD_LEG_ID IS NOT NULL
+    """
+    assert_column_lineage_equal(
+        sql,
+        [
+            (
+                TestColumnQualifierTuple("ld_leg_id", "src_tbl_1"),
+                TestColumnQualifierTuple("ld_leg_id", "trg_tbl"),
+            ),
+            (
+                TestColumnQualifierTuple("PICK_ARVL_RPTD_DTT", "src_tbl_2"),
+                TestColumnQualifierTuple("Actual_Pickup_Arrival", "trg_tbl"),
+            ),
+            (
+                TestColumnQualifierTuple("PICK_DPTR_RPTD_DTT", "src_tbl_2"),
+                TestColumnQualifierTuple("Actual_Pickup_Departure", "trg_tbl"),
+            ),
+        ],
+        test_sqlparse=False,
+    )
+
+
+def test_ctes_with_join():
+    sql = """create table random_table as
+
+        WITH
+        CTE1 as (
+            select x from zyx
+        ),
+        CTE2 as (
+            select x from abc
+        )
+
+        select x from CTE1 left join CTE2 on CTE1.x = CTE2.x
+    """
+    assert_column_lineage_equal(
+        sql,
+        [
+            (
+                TestColumnQualifierTuple("x", "zyx"),
+                TestColumnQualifierTuple("x", "random_table"),
+            ),
+            (
+                TestColumnQualifierTuple("x", "abc"),
+                TestColumnQualifierTuple("x", "random_table"),
+            ),
+        ],
+        test_sqlparse=False,
+    )
