@@ -19,11 +19,11 @@ def test_column_extract_source_columns():
 def test_handler_dummy():
     segment_mock = Mock()
     holder = SubQueryLineageHolder()
-    c_handler = ConditionalSegmentBaseHandler()
+    c_handler = ConditionalSegmentBaseHandler("snowflake")
     with pytest.raises(NotImplementedError):
         c_handler.handle(segment_mock, holder)
     with pytest.raises(NotImplementedError):
         c_handler.indicate(segment_mock)
-    s_handler = SegmentBaseHandler()
+    s_handler = SegmentBaseHandler("snowflake")
     with pytest.raises(NotImplementedError):
         s_handler.handle(segment_mock, holder)
